@@ -80,6 +80,7 @@ static char *monitors[] = {
 	NULL,
 };
 
+
 /**
 | Configuration parameters that matter to the core
 */
@@ -92,16 +93,19 @@ struct settings settings = {
 	.nodaemon     = false,
 };
 
+
 /*
 | True when Lsyncd daemonized itself.
 */
 static bool is_daemon = false;
 
+
 /*
 | The config file loaded by Lsyncd.
 */
 char * lsyncd_config_file = NULL;
 
+
 /*
 | False after first time Lsyncd started up.
 |
@@ -114,6 +118,7 @@ char * lsyncd_config_file = NULL;
 */
 static bool first_time = true;
 
+
 /*
 | Set by TERM or HUP signal handler
 | telling Lsyncd should end or reset ASAP.
@@ -123,11 +128,13 @@ volatile sig_atomic_t term = 0;
 volatile sig_atomic_t sigcode = 0;
 int pidfile_fd = 0;
 
+
 /*
 | The kernel's clock ticks per second.
 */
 static long clocks_per_sec;
 
+
 /**
  * signal handler
  */
@@ -136,6 +143,7 @@ sig_child(int sig) {
 	// nothing
 }
 
+
 /**
  * signal handler
  */
@@ -156,6 +164,7 @@ sig_handler( int sig )
 	}
 }
 
+
 /*
 | Non glibc builds need a real tms structure for the times( ) call
 */
@@ -166,6 +175,7 @@ sig_handler( int sig )
 	static struct tms * dummy_tms = &_dummy_tms;
 #endif
 
+
 /*
 | Returns the absolute path of a path.
 |
@@ -191,7 +201,6 @@ get_realpath( const char * rpath )
 }
 
 
-
 /*~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~*
 (              Logging                      )
  *~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~*/
@@ -256,18 +265,22 @@ add_logcat( const char *name, int priority )
 	if( !strcmp( "all", name ) )
 	{
 		settings.log_level = 99;
+
 		return true;
 	}
 
 	if( !strcmp( "scarce", name ) )
 	{
 		settings.log_level = LOG_WARNING;
+
 		return true;
 	}
 
 	// categories must start with a capital letter.
 	if( name[ 0 ] < 'A' || name[ 0 ] > 'Z' )
-		{ return false; }
+	{
+		return false;
+	}
 
 	if( !logcats[ name[ 0 ]- 'A' ] )
 	{
@@ -344,6 +357,7 @@ logstring0(
 		char ct[ 255 ];
 		// gets current timestamp hour:minute:second
 		time_t mtime;
+
 		time( &mtime );
 
 		strftime( ct, sizeof( ct ), "%T", localtime( &mtime ) );
@@ -358,18 +372,21 @@ logstring0(
 	}
 
 	// writes to file if configured so
-	if (settings.log_file)
+	if( settings.log_file )
 	{
 		FILE * flog = fopen( settings.log_file, "a" );
+
 		char * ct;
+
 		time_t mtime;
 
 		// gets current timestamp day-time-year
 		time( &mtime );
+
 		ct = ctime( &mtime );
 
 	 	// cuts trailing linefeed
- 		ct[ strlen( ct ) - 1] = 0;
+		ct[ strlen( ct ) - 1] = 0;
 
 		if( flog == NULL )
 		{
@@ -378,6 +395,7 @@ logstring0(
 				"Cannot open logfile [%s]!\n",
 				settings.log_file
 			);
+
 			exit( -1 );
 		}
 
@@ -420,7 +438,6 @@ printlogf0(lua_State *L,
 }
 
 
-
 /*~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~*
 (       Simple memory management            )
  *~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~*/
@@ -596,6 +613,7 @@ pipe_tidy( struct observance * observance )
 */
 static int runner;
 
+
 /*
 | Dummy variable of which it's address is used as
 | the cores index n the lua registry to
@@ -612,9 +630,9 @@ close_exec_fd( int fd )
 {
 	int flags;
 
-    flags = fcntl( fd, F_GETFD );
+	flags = fcntl( fd, F_GETFD );
 
-    if( flags == -1 )
+	if( flags == -1 )
 	{
 		logstring( "Error", "cannot get descriptor flags!" );
 		exit( -1 );
@@ -638,9 +656,9 @@ non_block_fd( int fd )
 {
 	int flags;
 
-    flags = fcntl( fd, F_GETFL );
+	flags = fcntl( fd, F_GETFL );
 
-    if( flags == -1 )
+	if( flags == -1 )
 	{
 		logstring( "Error", "cannot get status flags!" );
 		exit( -1 );
@@ -659,7 +677,8 @@ non_block_fd( int fd )
 | Writes a pid file.
 */
 static void
-write_pidfile(
+write_pidfile
+(
 	lua_State *L,
 	const char *pidfile
 )
@@ -952,12 +971,13 @@ user_obs_tidy( struct observance *obs )
 }
 
 
-/*~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~*
-(     Library calls for the runner          )
- *~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~*/
+/******************************.
+* Library calls for the runner *
+'******************************/
 
 
-static void daemonize( lua_State *L );
+static void daemonize( lua_State *L, const char *pidfile );
+
 int l_stackdump( lua_State* L );
 
 
@@ -981,7 +1001,9 @@ l_log( lua_State *L )
 
 	// skips filtered messages
 	if( priority > settings.log_level )
-		{ return 0; }
+	{
+		return 0;
+	}
 
 	// replaces non string values
 	{
@@ -1212,9 +1234,14 @@ l_exec( lua_State *L )
 
 	// prepares the arguments
 	argv = s_calloc( argc + 2, sizeof( char * ) );
+
 	argv[ 0 ] = binary;
+
 	for( i = 1; i <= argc; i++ )
-		{ argv[i] = luaL_checkstring( L, i + li ); }
+	{
+		argv[i] = luaL_checkstring( L, i + li );
+	}
+
 	argv[ i ] = NULL;
 
 	// the fork!
@@ -1224,7 +1251,9 @@ l_exec( lua_State *L )
 	{
 		// replaces stdin for pipes
 		if( pipe_text )
-			{ dup2( pipefd[ 0 ], STDIN_FILENO ); }
+		{
+			dup2( pipefd[ 0 ], STDIN_FILENO );
+		}
 
 		// if lsyncd runs as a daemon and has a logfile it will redirect
 		// stdout/stderr of child processes to the logfile.
@@ -1325,36 +1354,56 @@ l_realdir( lua_State *L )
 	const char *rdir = luaL_checkstring(L, 1);
 	char *adir = get_realpath(rdir);
 
-	if (!adir) {
-		printlogf(L, "Error", "failure getting absolute path of [%s]", rdir);
+	if( !adir )
+	{
+		printlogf(
+			L, "Error",
+			"failure getting absolute path of [%s]",
+			rdir
+		);
+
 		return 0;
 	}
 
 	{
 		// makes sure its a directory
 	    struct stat st;
-	    if (stat(adir, &st)) {
-			printlogf(L, "Error",
-				"cannot get absolute path of dir '%s': %s", rdir, strerror(errno));
-			free(adir);
+	    if( stat( adir, &st ) )
+		{
+			printlogf(
+				L, "Error",
+				"cannot get absolute path of dir '%s': %s",
+				rdir,
+				strerror( errno )
+			);
+
+			free( adir );
+
 			return 0;
 		}
 
-	    if (!S_ISDIR(st.st_mode)) {
-			printlogf(L, "Error",
-				"cannot get absolute path of dir '%s': is not a directory", rdir);
-			free(adir);
+	    if( !S_ISDIR( st.st_mode ) )
+		{
+			printlogf(
+				L, "Error",
+				"cannot get absolute path of dir '%s': is not a directory",
+				rdir
+			);
+
+			free( adir );
+
 			return 0;
 	    }
 	}
 
 	// returns absolute path with a concated '/'
-	luaL_buffinit(L, &b);
-	luaL_addstring(&b, adir);
-	luaL_addchar(&b, '/');
-	luaL_pushresult(&b);
+	luaL_buffinit( L, &b );
+	luaL_addstring( &b, adir );
+	luaL_addchar( &b, '/' );
+	luaL_pushresult( &b );
+
+	free( adir );
 
-	free(adir);
 	return 1;
 }
 
@@ -1380,35 +1429,43 @@ l_stackdump( lua_State * L )
 		switch( t )
 		{
 			case LUA_TSTRING:
+
 				printlogf(
 					L, "Debug",
 					"%d string: '%s'",
 					i, lua_tostring( L,  i )
 				);
+
 				break;
 
 			case LUA_TBOOLEAN:
+
 				printlogf(
 					L, "Debug",
 					"%d boolean %s",
 					i, lua_toboolean( L, i ) ? "true" : "false"
 				);
+
 				break;
 
 			case LUA_TNUMBER:
+
 				printlogf(
 					L, "Debug",
 					"%d number: %g",
 					i, lua_tonumber( L, i )
 				);
+
 				break;
 
 			default:
+
 				printlogf(
 					L, "Debug",
 					"%d %s",
 					i, lua_typename( L, t )
 				);
+
 				break;
 		}
 	}
@@ -1428,12 +1485,14 @@ l_stackdump( lua_State * L )
 |     values are boolean true on dirs.
 */
 static int
-l_readdir ( lua_State *L )
+l_readdir( lua_State *L )
 {
 	const char * dirname = luaL_checkstring( L, 1 );
+
 	DIR *d;
 
 	d = opendir( dirname );
+
 	if( d == NULL )
 	{
 		printlogf(
@@ -1451,16 +1510,15 @@ l_readdir ( lua_State *L )
 		struct dirent *de = readdir( d );
 		bool isdir;
 
-		if( de == NULL )
+		if( de == NULL ) // finished
 		{
-			// finished
 			break;
 		}
 
 		// ignores . and ..
 		if(
-			!strcmp( de->d_name, "."  ) ||
-			!strcmp( de->d_name, ".." )
+			!strcmp( de->d_name, "."  )
+			|| !strcmp( de->d_name, ".." )
 		)
 		{
 			continue;
@@ -1475,6 +1533,7 @@ l_readdir ( lua_State *L )
 				strlen( de->d_name ) +
 				2
 			);
+
 			struct stat st;
 
 			strcpy( entry, dirname );
@@ -1500,6 +1559,7 @@ l_readdir ( lua_State *L )
 	}
 
 	closedir( d );
+
 	return 1;
 }
 
@@ -1514,7 +1574,7 @@ l_readdir ( lua_State *L )
 |
 */
 int
-l_terminate(lua_State *L)
+l_terminate( lua_State *L )
 {
 	int exitcode = luaL_checkinteger( L, 1 );
 
@@ -1534,6 +1594,7 @@ static int
 l_configure( lua_State *L )
 {
 	const char * command = luaL_checkstring( L, 1 );
+
 	if( !strcmp( command, "running" ) )
 	{
 		// set by runner after first initialize
@@ -1546,22 +1607,22 @@ l_configure( lua_State *L )
 			settings.log_syslog = true;
 
 			const char * log_ident =
-				settings.log_ident ?
-					settings.log_ident :
-					"lsyncd";
+				settings.log_ident
+				? settings.log_ident
+				: "lsyncd";
 
 			openlog( log_ident, 0, settings.log_facility );
 		}
 
 		if( !settings.nodaemon && !is_daemon )
 		{
-			logstring( "Debug", "daemonizing now." );
-			daemonize( L );
-		}
+			logstring( "Normal", "--- Startup, daemonizing ---" );
 
-		if( settings.pidfile )
+			daemonize( L, settings.pidfile );
+		}
+		else
 		{
-			write_pidfile( L, settings.pidfile );
+			logstring( "Normal", "--- Startup ---" );
 		}
 
 	}
@@ -1590,8 +1651,7 @@ l_configure( lua_State *L )
 			free( settings.pidfile );
 		}
 
-		settings.pidfile =
-			s_strdup( file );
+		settings.pidfile = s_strdup( file );
 	}
 	else if( !strcmp( command, "logfacility" ) )
 	{
@@ -1635,8 +1695,10 @@ l_configure( lua_State *L )
 	{
 		const char * ident = luaL_checkstring( L, 2 );
 
-		if (settings.log_ident)
-			{ free(settings.log_ident); }
+		if( settings.log_ident )
+		{
+			free( settings.log_ident );
+		}
 
 		settings.log_ident = s_strdup( ident );
 	}
@@ -1767,6 +1829,7 @@ l_nonobserve_fd( lua_State *L )
 	return 0;
 }
 
+
 /*
 | The Lsnycd's core library
 */
@@ -1785,6 +1848,7 @@ static const luaL_Reg lsyncdlib[] =
 	{ NULL,             NULL            }
 };
 
+
 /*
 | Adds a number in seconds to a jiffy timestamp.
 */
@@ -1817,6 +1881,7 @@ l_jiffies_add( lua_State *L )
 	}
 }
 
+
 /*
 | Subracts two jiffy timestamps resulting in a number in seconds
 | or substracts a jiffy by a number in seconds resulting a jiffy timestamp.
@@ -1849,6 +1914,7 @@ l_jiffies_sub( lua_State *L )
 	return 1;
 }
 
+
 /*
 | Compares two jiffy timestamps
 */
@@ -1863,6 +1929,7 @@ l_jiffies_eq( lua_State *L )
 	return 1;
 }
 
+
 /*
 * True if jiffy1 timestamp is eariler than jiffy2 timestamp
 */
@@ -1877,6 +1944,7 @@ l_jiffies_lt( lua_State *L )
 	return 1;
 }
 
+
 /*
 | True if jiffy1 before or equals jiffy2
 */
@@ -1897,7 +1965,7 @@ l_jiffies_le(lua_State *L)
 void
 register_lsyncd( lua_State *L )
 {
-	luaL_register( L, LSYNCD_LIBNAME, lsyncdlib );
+	lua_compat_register( L, LSYNCD_LIBNAME, lsyncdlib );
 	lua_setglobal( L, LSYNCD_LIBNAME );
 
 	// creates the metatable for the jiffies ( timestamps ) userdata
@@ -1971,6 +2039,7 @@ load_runner_func(
 	lua_remove( L, -2 );
 }
 
+
 /*
 | Daemonizes.
 |
@@ -1981,7 +2050,10 @@ load_runner_func(
 |      might actually close the monitors fd!
 */
 static void
-daemonize( lua_State *L )
+daemonize(
+	lua_State *L,       // the lua state
+	const char *pidfile // if not NULL write pidfile
+)
 {
 	pid_t pid, sid;
 
@@ -1998,14 +2070,20 @@ daemonize( lua_State *L )
 		exit( -1 );
 	}
 
-	if (pid > 0)
+	if( pid > 0 )
 	{
 		 // parent process returns to shell
 	 	exit( 0 );
 	}
 
+	if( pidfile )
+	{
+		write_pidfile( L, pidfile );
+	}
+
 	// detaches the new process from the parent process
 	sid = setsid( );
+
 	if( sid < 0 )
 	{
 		printlogf(
@@ -2338,6 +2416,7 @@ masterloop(lua_State *L)
 	}
 }
 
+
 /*
 | The effective main for one run.
 |
@@ -2356,6 +2435,7 @@ main1( int argc, char *argv[] )
 
 	// load Lua
 	L = luaL_newstate( );
+
 	luaL_openlibs( L );
 	{
 		// checks the lua version
@@ -2433,7 +2513,6 @@ main1( int argc, char *argv[] )
 	// registers Lsycnd's core library
 	register_lsyncd( L );
 
-
 	if( check_logcat( "Debug" ) <= settings.log_level )
 	{
 		// printlogf doesnt support %ld :-(
@@ -2591,7 +2670,6 @@ main1( int argc, char *argv[] )
 		}
 	}
 
-
 	// checks if there is a "-help" or "--help"
 	{
 		int i;
@@ -2719,15 +2797,11 @@ main1( int argc, char *argv[] )
 	}
 
 #ifdef WITH_INOTIFY
-
 	open_inotify( L );
-
 #endif
 
 #ifdef WITH_FSEVENTS
-
 	open_fsevents( L );
-
 #endif
 
 	// adds signal handlers
@@ -2805,6 +2879,7 @@ main1( int argc, char *argv[] )
 	return 0;
 }
 
+
 /*
 | Main
 */
@@ -2814,6 +2889,9 @@ main( int argc, char * argv[ ] )
 	// gets a kernel parameter
 	clocks_per_sec = sysconf( _SC_CLK_TCK );
 
+	setlinebuf( stdout );
+	setlinebuf( stderr );
+
 	while( !term ) {
 		main1( argc, argv );
 	}
