@@ -1,6 +1,6 @@
-#!/usr/bin/lua
 -- a heavy duty test.
 -- makes thousends of random changes to the source tree
+
 require( 'posix' )
 dofile( 'tests/testlib.lua' )
 
@@ -11,7 +11,7 @@ cwriteln( '****************************************************************' )
 local tdir, srcdir, trgdir = mktemps( )
 
 -- makes some startup data
-churn( srcdir, 100 )
+churn( srcdir, 100, true )
 
 local logs = { }
 -- logs =  { "-log", "Delay", "-log", "Fsevents" }
@@ -20,14 +20,14 @@ local pid = spawn(
 	'-nodaemon',
 	'-delay', '5',
 	'-rsync', srcdir, trgdir,
-	unpack( logs )
+	table.unpack( logs )
 )
 
 cwriteln( 'waiting for Lsyncd to startup' )
 
 posix.sleep( 1 )
 
-churn( srcdir, 500 )
+churn( srcdir, 500, false )
 
 cwriteln( 'waiting for Lsyncd to finish its jobs.' )
 
@@ -48,7 +48,7 @@ else
 	cwriteln( 'Signal terminating diff = ', code )
 end
 
-if exitcode ~= 0
+if code ~= 0
 then
 	os.exit( 1 )
 else
