@@ -1,4 +1,3 @@
-#!/usr/bin/lua
 -- a heavy duty test.
 -- makes thousends of random changes to the source tree
 
@@ -15,7 +14,7 @@ cwriteln( '( for current user                                             )' )
 local tdir, srcdir, trgdir = mktemps()
 
 -- makes some startup data
-churn( srcdir, 100 )
+churn( srcdir, 5, true )
 
 local logs = {}
 logs =  { '-log', 'Delay' }
@@ -29,20 +28,23 @@ local pid = spawn(
 	srcdir,
 	'localhost',
 	trgdir,
-	unpack(logs)
+	table.unpack(logs)
 )
 
 cwriteln( 'waiting for Lsyncd to startup' )
 posix.sleep( 1 )
 
-churn( srcdir, 100 )
+churn( srcdir, 150, false )
 
 cwriteln( 'waiting for Lsyncd to finish its jobs.' )
 posix.sleep( 10 )
 
 cwriteln( 'killing the Lsyncd daemon' )
+
 posix.kill(pid)
-local _, exitmsg, lexitcode = posix.wait(lpid)
+
+local _, exitmsg, lexitcode = posix.wait( lpid )
+
 cwriteln( 'Exitcode of Lsyncd = ', exitmsg, ' ', lexitcode )
 
 _, result, code = os.execute( 'diff -r ' .. srcdir .. ' ' .. trgdir )
@@ -54,7 +56,7 @@ else
 	cwriteln( 'Signal terminating diff = ', code )
 end
 
-if exitcode ~= 0
+if code ~= 0
 then
 	os.exit( 1 )
 else
